@@ -15,7 +15,6 @@ from typing import List, Optional, Tuple, Union
 from anchorpoint.textsequences import TextPassage, TextSequence
 from anchorpoint.utils._helper import _is_iterable_non_string, InfiniteValue
 from anchorpoint.utils.ranges import Range, RangeSet
-from marshmallow import ValidationError
 
 
 class TextSelectionError(Exception):
@@ -66,7 +65,7 @@ class TextQuoteSelector:
             return ("", text, "")
         elif text.count("|") == 2:
             return tuple([*text.split("|")])
-        raise ValidationError(
+        raise TextSelectionError(
             "If the 'text' field includes | pipe separators, it must contain exactly "
             "two, separating the string into 'prefix', 'exact', and 'suffix'."
         )
@@ -146,8 +145,9 @@ class TextQuoteSelector:
             # Getting indices from match group 1 (in the parentheses),
             # not match 0 which includes prefix and suffix
             return TextPositionSelector(match.start(1), match.end(1))
+        text_sample = text[:100] + "..." if len(text) > 100 else text
         raise TextSelectionError(
-            f'Unable to find pattern "{self.passage_regex()}" in text: "{text}"'
+            f'Unable to find pattern "{self.passage_regex()}" in text: "{text_sample}"'
         )
 
     def is_unique_in(self, text: str) -> bool:
@@ -418,7 +418,7 @@ class TextPositionSelector(Range):
 
 
 class TextPositionSet(RangeSet):
-    """
+    r"""
     A set of TextPositionSelectors.
 
     Implements the interface of Python :py:class:`set`\s.
@@ -472,8 +472,7 @@ class TextPositionSet(RangeSet):
         return TextPositionSet([text_range - value for text_range in self])
 
     def as_quotes(self, text: str) -> List[TextQuoteSelector]:
-        quotes = [selector.unique_quote_selector(text) for selector in self.ranges()]
-        return quotes
+        return [selector.unique_quote_selector(text) for selector in self.ranges()]
 
     def as_text_sequence(self, text: str, include_nones: bool = True) -> TextSequence:
         """
