@@ -25,7 +25,7 @@ import re
 from collections.abc import Iterable
 from anchorpoint.utils._helper import (
     _LinkedList,
-    _InfiniteValue,
+    InfiniteValue,
     _is_iterable_non_string,
 )
 
@@ -151,10 +151,15 @@ class Range:
         keywords `include_start` and `include_end` to `True` or `False`.
         """
         # process kwargs
-        start = kwargs.get("start", _InfiniteValue(negative=True))
-        end = kwargs.get("end", _InfiniteValue(negative=False))
+        start = kwargs.get("start", InfiniteValue(negative=True))
+        end = kwargs.get("end", InfiniteValue(negative=False))
+
+        # prevent None
+        if start is None:
+            start = 0
         if end is None:
-            end = _InfiniteValue(negative=False)
+            end = InfiniteValue(negative=False)
+
         include_start = kwargs.get("include_start", True)
         include_end = kwargs.get("include_end", False)
         self.include_start = include_start
@@ -930,7 +935,7 @@ class RangeSet(Iterable):
         RangeSet.
         """
         # convert to a RangeSet
-        rng_set = RangeSet._to_rangeset(rng_set)
+        rng_set = self.__class__._to_rangeset(rng_set)
         # do O(n^2) difference algorithm
         # TODO rewrite to increase efficiency by short-circuiting
         intersections = [
@@ -939,7 +944,7 @@ class RangeSet(Iterable):
         intersections = [
             rng for rng in intersections if rng is not None and not rng.isempty()
         ]
-        return RangeSet(intersections)
+        return self.__class__(intersections)
 
     def intersection_update(self, rng_set):
         """
